@@ -29,7 +29,7 @@ struct _GgvPostscriptViewPrivate {
 	GtkWidget *gs;
 	GtkObject *hadj, *vadj;
 
-	GNOME_GGV_Media def_media;
+	GNOME_GGV_Size def_size;
 	GNOME_GGV_Orientation def_orientation;
 
 	gint magstep;
@@ -46,8 +46,8 @@ struct _GgvPostscriptViewPrivate {
 };
 
 struct _GgvPostscriptViewClassPrivate {
-	BonoboUINode   *media_menus;
-	gchar          **media_paths;
+	BonoboUINode   *size_menus;
+	gchar          **size_paths;
 };
 
 enum {
@@ -58,8 +58,8 @@ enum {
 	PROP_ANTIALIASING,
 	PROP_DEFAULT_ORIENTATION,
 	PROP_OVERRIDE_ORIENTATION,
-	PROP_DEFAULT_MEDIA,
-	PROP_OVERRIDE_MEDIA,
+	PROP_DEFAULT_SIZE,
+	PROP_OVERRIDE_SIZE,
 	PROP_RESPECT_EOF,
 	PROP_WATCH_FILE
 };
@@ -116,7 +116,7 @@ load_ps_from_stream (BonoboPersistStream *ps,
 	Bonobo_Stream_copyTo(stream, ps_view->priv->tmp_name,
 						 -1, &bytes_read, &bytes_written, ev);
 	gtk_gs_load(GTK_GS(ps_view->priv->gs), ps_view->priv->tmp_name);
-	gtk_gs_set_page_media(GTK_GS(ps_view->priv->gs), -1, 0);
+	gtk_gs_set_page_size(GTK_GS(ps_view->priv->gs), -1, 0);
 	gtk_gs_goto_page(GTK_GS(ps_view->priv->gs), 0);
 }
 
@@ -267,7 +267,7 @@ listener_Toggle_cb (BonoboUIComponent *uic, const char *path,
 
 	static gchar *properties[][2] = {
 		{ "OverrideOrientation", "override_orientation" },
-		{ "OverrideMedia", "override_media" },
+		{ "OverrideSize", "override_size" },
 		{ "RespectEOF", "respect_eof" },
 		{ "Antialiasing", "antialiasing" },
 		{ "WatchFile", "watch_file" },
@@ -312,12 +312,12 @@ listener_Toggle_cb (BonoboUIComponent *uic, const char *path,
 
 	
 static void
-listener_Media_cb(BonoboUIComponent *uic, const char *path,
+listener_Size_cb(BonoboUIComponent *uic, const char *path,
 				  Bonobo_UIComponent_EventType type, const char *state,
 				  gpointer user_data)
 {
 	GgvPostscriptView *ps_view;
-	GNOME_GGV_Media media;
+	GNOME_GGV_Size size;
 	BonoboArg *arg;
 
 	g_return_if_fail(user_data != NULL);
@@ -331,14 +331,14 @@ listener_Media_cb(BonoboUIComponent *uic, const char *path,
 
 	ps_view = GGV_POSTSCRIPT_VIEW(user_data);
 
-	media = CORBA_string_dup(path);
+	size = CORBA_string_dup(path);
 
-	arg = bonobo_arg_new(TC_GNOME_GGV_Media);
-	BONOBO_ARG_SET_GENERAL(arg, media, TC_GNOME_GGV_Media,
-						   GNOME_GGV_Media, NULL);
+	arg = bonobo_arg_new(TC_GNOME_GGV_Size);
+	BONOBO_ARG_SET_GENERAL(arg, size, TC_GNOME_GGV_Size,
+						   GNOME_GGV_Size, NULL);
 
 	bonobo_property_bag_set_value(ps_view->priv->property_bag,
-								  "media", arg, NULL);
+								  "size", arg, NULL);
 
 	bonobo_arg_release(arg);
 }
@@ -415,25 +415,25 @@ sync_orientation_items(GgvPostscriptView *ps_view)
 }
 
 static void
-sync_media_items(GgvPostscriptView *ps_view)
+sync_size_items(GgvPostscriptView *ps_view)
 {
 	CORBA_Environment ev;
 	gint i;
-	gboolean val, media_state;
+	gboolean val, size_state;
 	gchar **paths;
 
 	CORBA_exception_init(&ev);
 
-	paths = GGV_POSTSCRIPT_VIEW_CLASS(GTK_OBJECT(ps_view)->klass)->priv->media_paths;
-	val = gtk_gs_get_override_media(GTK_GS(ps_view->priv->gs));
+	paths = GGV_POSTSCRIPT_VIEW_CLASS(GTK_OBJECT(ps_view)->klass)->priv->size_paths;
+	val = gtk_gs_get_override_size(GTK_GS(ps_view->priv->gs));
 	bonobo_ui_component_set_prop(ps_view->priv->uic, paths[0],
 								 "state", val?"1":"0", NULL);
 	for(i = 1; paths[i] != NULL; i++) {
 		bonobo_ui_component_set_prop(ps_view->priv->uic, paths[i],
 									 "sensitive", val?"1":"0", NULL);
-		media_state = i - 1 == gtk_gs_get_default_media(GTK_GS(ps_view->priv->gs));
+		size_state = i - 1 == gtk_gs_get_default_size(GTK_GS(ps_view->priv->gs));
 		bonobo_ui_component_set_prop(ps_view->priv->uic, paths[i],
-									 "state", media_state?"1":"0", NULL);
+									 "state", size_state?"1":"0", NULL);
 	}
 }
 
@@ -445,7 +445,7 @@ ggv_postscript_view_create_ui(GgvPostscriptView *ps_view)
 		BONOBO_UI_VERB ("PrevPage", verb_PrevPage_cb),
 		BONOBO_UI_VERB_END
 	};
-	BonoboUINode *new_media_menus;
+	BonoboUINode *new_size_menus;
 	BonoboUINode *ui_root;
 	GgvPostscriptViewClass *klass = GGV_POSTSCRIPT_VIEW_CLASS(GTK_OBJECT(ps_view)->klass);
 	gint i;
@@ -455,19 +455,22 @@ ggv_postscript_view_create_ui(GgvPostscriptView *ps_view)
 
 	/* Set up the UI from an XML file. */
 #if 1
-	ui_root = bonobo_ui_util_new_ui(ps_view->priv->uic, DATADIR,
-									"ggv-postscript-view-ui.xml", "GgvPostscriptView");
+	ui_root = bonobo_ui_util_new_ui(ps_view->priv->uic, 
+									DATADIR "/gnome/ui/ggv-postscript-view-ui.xml",
+									DATADIR,
+									"GgvPostscriptView");
 	bonobo_ui_util_translate_ui(ui_root);
 	bonobo_ui_component_set_tree(ps_view->priv->uic, "/", ui_root, NULL);
 #else
-	bonobo_ui_util_set_ui(ps_view->priv->uic, "ggv-postscript-view-ui.xml", 
-						  DATADIR, "GgvPostscriptView");
+	bonobo_ui_util_set_ui(ps_view->priv->uic, DATADIR,
+						  "ggv-postscript-view-ui.xml", 
+						  "GgvPostscriptView");
 #endif
 
-	new_media_menus = bonobo_ui_node_copy(klass->priv->media_menus, TRUE);
-	if(new_media_menus)
-		bonobo_ui_component_set_tree(ps_view->priv->uic, "/menu/View/Media",
-									 new_media_menus, NULL);
+	new_size_menus = bonobo_ui_node_copy(klass->priv->size_menus, TRUE);
+	if(new_size_menus)
+		bonobo_ui_component_set_tree(ps_view->priv->uic, "/menu/View/Size",
+									 new_size_menus, NULL);
 
 	bonobo_ui_component_add_listener(ps_view->priv->uic, "OrientationPortrait",
 									 listener_Orientation_cb, ps_view);
@@ -479,12 +482,12 @@ ggv_postscript_view_create_ui(GgvPostscriptView *ps_view)
 									 listener_Orientation_cb, ps_view);
 	bonobo_ui_component_add_listener(ps_view->priv->uic, "OverrideOrientation",
 									 listener_Toggle_cb, ps_view);
-	for(i = 1; klass->priv->media_paths[i] != NULL; i++) {
+	for(i = 1; klass->priv->size_paths[i] != NULL; i++) {
 		bonobo_ui_component_add_listener(ps_view->priv->uic,
-										 klass->priv->media_paths[i] + strlen("/commands/"),
-										 listener_Media_cb, ps_view);
+										 klass->priv->size_paths[i] + strlen("/commands/"),
+										 listener_Size_cb, ps_view);
 	}
-	bonobo_ui_component_add_listener(ps_view->priv->uic, "OverrideMedia",
+	bonobo_ui_component_add_listener(ps_view->priv->uic, "OverrideSize",
 									 listener_Toggle_cb, ps_view);
 
 	bonobo_ui_component_add_verb_list_with_data(ps_view->priv->uic,
@@ -493,7 +496,7 @@ ggv_postscript_view_create_ui(GgvPostscriptView *ps_view)
 
 	set_page_item_sensitivity(ps_view);
 	sync_orientation_items(ps_view);
-	sync_media_items(ps_view);
+	sync_size_items(ps_view);
 }
 
 static void
@@ -504,7 +507,7 @@ ggv_postscript_view_get_prop(BonoboPropertyBag *bag,
 							 gpointer           user_data)
 {
 	GgvPostscriptView *ps_view;
-	gchar *media;
+	gchar *size;
 
 	g_return_if_fail(user_data != NULL);
 	g_return_if_fail(GGV_IS_POSTSCRIPT_VIEW(user_data));
@@ -526,21 +529,21 @@ ggv_postscript_view_get_prop(BonoboPropertyBag *bag,
 			CORBA_TRUE:CORBA_FALSE;
 		break;
 	}
-	case PROP_DEFAULT_MEDIA: {
-		g_assert(arg->_type == TC_GNOME_GGV_Media);
+	case PROP_DEFAULT_SIZE: {
+		g_assert(arg->_type == TC_GNOME_GGV_Size);
 
-		media = gtk_gs_defaults_get_paper_sizes()
-			[gtk_gs_get_default_media(GTK_GS(ps_view->priv->gs))].name;
+		size = gtk_gs_defaults_get_paper_sizes()
+			[gtk_gs_get_default_size(GTK_GS(ps_view->priv->gs))].name;
 
-		*(GNOME_GGV_Media *)arg->_value =
-			CORBA_string_dup(media);
+		*(GNOME_GGV_Size *)arg->_value =
+			CORBA_string_dup(size);
 		break;
 	}
-	case PROP_OVERRIDE_MEDIA: {
+	case PROP_OVERRIDE_SIZE: {
 		g_assert(arg->_type == TC_CORBA_boolean);
 
 		*(CORBA_boolean *)arg->_value =
-			gtk_gs_get_override_media(GTK_GS(ps_view->priv->gs))?
+			gtk_gs_get_override_size(GTK_GS(ps_view->priv->gs))?
 			CORBA_TRUE:CORBA_FALSE;
 		break;
 	}
@@ -626,30 +629,30 @@ ggv_postscript_view_set_prop(BonoboPropertyBag *bag,
 		 sync_orientation_items(ps_view);
 		 break;
 	}
-	case PROP_DEFAULT_MEDIA: {
-		gint media;
-		gchar *media_name;
+	case PROP_DEFAULT_SIZE: {
+		gint size;
+		gchar *size_name;
 
-		g_assert(arg->_type == TC_GNOME_GGV_Media);
+		g_assert(arg->_type == TC_GNOME_GGV_Size);
 		
-		media_name = *(GNOME_GGV_Media *)arg->_value;
+		size_name = *(GNOME_GGV_Size *)arg->_value;
 
-		media = gtk_gs_get_media_index(media_name,
+		size = gtk_gs_get_size_index(size_name,
 									   gtk_gs_defaults_get_paper_sizes());
 
-		gtk_gs_set_default_media(GTK_GS(ps_view->priv->gs), media);
-		sync_media_items(ps_view);
+		gtk_gs_set_default_size(GTK_GS(ps_view->priv->gs), size);
+		sync_size_items(ps_view);
 
 		break;
 	}
-	case PROP_OVERRIDE_MEDIA: {
-		 gtk_gs_set_override_media(GTK_GS(ps_view->priv->gs),
+	case PROP_OVERRIDE_SIZE: {
+		 gtk_gs_set_override_size(GTK_GS(ps_view->priv->gs),
 								   *(CORBA_boolean *)arg->_value);
-		 sync_media_items(ps_view);
+		 sync_size_items(ps_view);
 		 break;
 	}
 	case PROP_ANTIALIASING: {
-		 gtk_gs_set_override_media(GTK_GS(ps_view->priv->gs),
+		 gtk_gs_set_override_size(GTK_GS(ps_view->priv->gs),
 								   *(CORBA_boolean *)arg->_value);
 		 break;
 	}
@@ -959,28 +962,28 @@ ggv_postscript_view_class_init(GgvPostscriptViewClass *klass)
 
 	ggv_postscript_view_parent_class = gtk_type_class(PARENT_TYPE);
 
-	/* init media menu template */
+	/* init size menu template */
 	placeholder = bonobo_ui_node_new("placeholder");
-	bonobo_ui_node_set_attr(placeholder, "name", "MediaList");
+	bonobo_ui_node_set_attr(placeholder, "name", "SizeList");
 	bonobo_ui_node_set_attr(placeholder, "delimit", "top");
 	papersizes = gtk_gs_defaults_get_paper_sizes();
-	klass->priv->media_paths = g_new0(gchar *, n + 2);
+	klass->priv->size_paths = g_new0(gchar *, n + 2);
 	for(i = 0; i < n; i++) {
 		item = bonobo_ui_node_new("menuitem");
-		klass->priv->media_paths[i + 1] =
+		klass->priv->size_paths[i + 1] =
 			g_strdup_printf("/commands/%s", papersizes[i].name);
 		bonobo_ui_node_set_attr(item, "name", papersizes[i].name);
 		enc_str = bonobo_ui_util_encode_str(_(papersizes[i].name));
 		bonobo_ui_node_set_attr(item, "label", enc_str);
 		g_free(enc_str);
 		bonobo_ui_node_set_attr(item, "type", "radio");
-		bonobo_ui_node_set_attr(item, "group", "Media");
+		bonobo_ui_node_set_attr(item, "group", "Size");
 		bonobo_ui_node_set_attr(item, "verb", "");
 		bonobo_ui_node_add_child(placeholder, item);
 	}
-	klass->priv->media_paths[0] = "/commands/OverrideMedia";
-	klass->priv->media_paths[n + 1] = NULL;
-	klass->priv->media_menus = placeholder;
+	klass->priv->size_paths[0] = "/commands/OverrideSize";
+	klass->priv->size_paths[n + 1] = NULL;
+	klass->priv->size_menus = placeholder;
 
 	gtk_object_class_add_signals(object_class, ggv_postscript_view_signals, LAST_SIGNAL);
 
@@ -1097,17 +1100,17 @@ ggv_postscript_view_construct(GgvPostscriptView *ps_view,
 							PROP_DEFAULT_ORIENTATION, TC_GNOME_GGV_Orientation, NULL,
 							_("Default orientation"), 
 							BONOBO_PROPERTY_READABLE | BONOBO_PROPERTY_WRITEABLE);
-	bonobo_property_bag_add(ps_view->priv->property_bag, "media",
-							PROP_DEFAULT_MEDIA, TC_GNOME_GGV_Media, NULL,
-							_("Default media"), 
+	bonobo_property_bag_add(ps_view->priv->property_bag, "size",
+							PROP_DEFAULT_SIZE, TC_GNOME_GGV_Size, NULL,
+							_("Default size"), 
 							BONOBO_PROPERTY_READABLE | BONOBO_PROPERTY_WRITEABLE);
 	bonobo_property_bag_add(ps_view->priv->property_bag, "override_orientation",
 							PROP_OVERRIDE_ORIENTATION, TC_CORBA_boolean, NULL,
 							_("Override document orientation"), 
 							BONOBO_PROPERTY_READABLE | BONOBO_PROPERTY_WRITEABLE);
-	bonobo_property_bag_add(ps_view->priv->property_bag, "override_media",
-							PROP_OVERRIDE_MEDIA, TC_CORBA_boolean, NULL,
-							_("Override document media"), 
+	bonobo_property_bag_add(ps_view->priv->property_bag, "override_size",
+							PROP_OVERRIDE_SIZE, TC_CORBA_boolean, NULL,
+							_("Override document size"), 
 							BONOBO_PROPERTY_READABLE | BONOBO_PROPERTY_WRITEABLE);
 	bonobo_property_bag_add(ps_view->priv->property_bag, "respect_eof",
 							PROP_RESPECT_EOF, TC_CORBA_boolean, NULL,
