@@ -437,7 +437,7 @@ override_paper_callback(GtkWidget *widget, gpointer data)
         GtkGS *gs;
 
         gs = GTK_GS(ggv->gs);
-        gtk_gs_set_override_media (gs, GTK_CHECK_MENU_ITEM(widget)->active);
+        gtk_gs_set_override_size (gs, GTK_CHECK_MENU_ITEM(widget)->active);
         synchronize_paper_items(ggv);
 }
 
@@ -997,8 +997,8 @@ void paper_callback(GtkWidget *widget, gpointer *data)
                 return;
         }
 
-        gs->default_media = GPOINTER_TO_INT(wwd->data);
-        gtk_gs_set_page_media(gs, -1, gs->current_page);
+        gs->default_size = GPOINTER_TO_INT(wwd->data);
+        gtk_gs_set_page_size(gs, -1, gs->current_page);
 }
 
 void zoom_to_fit_callback(GtkWidget *widget, gpointer data)
@@ -1048,8 +1048,8 @@ void zoomout_callback(GtkWidget *widget, gpointer data)
 
 void prefs_destroy_callback(GtkWidget *w, ggv_prefs *p)
 {
-        g_free(p->media_choice);
-        p->media_choice = NULL;
+        g_free(p->size_choice);
+        p->size_choice = NULL;
         p->pbox = NULL;
 }
 
@@ -1073,11 +1073,11 @@ void prefs_apply_callback(GtkWidget *w, gint page, ggv_prefs *p)
                 g_free(ggv_print_cmd);
         ggv_print_cmd = g_strdup(gtk_entry_get_text(GTK_ENTRY(p->print)));
 
-        active = gtk_menu_get_active(GTK_MENU(gtk_option_menu_get_menu(GTK_OPTION_MENU(p->media))));
+        active = gtk_menu_get_active(GTK_MENU(gtk_option_menu_get_menu(GTK_OPTION_MENU(p->size))));
         n = gtk_gs_defaults_get_paper_count();
         for(i = 0; i < n; i++)
-                if(active == p->media_choice[i]) {
-                        gtk_gs_defaults_set_media(i);
+                if(active == p->size_choice[i]) {
+                        gtk_gs_defaults_set_size(i);
                         break;
                 }
 
@@ -1108,7 +1108,7 @@ void prefs_apply_callback(GtkWidget *w, gint page, ggv_prefs *p)
         gtk_gs_defaults_set_respect_eof(GTK_TOGGLE_BUTTON(p->respect_eof)->active);
         gtk_gs_defaults_set_watch_doc(GTK_TOGGLE_BUTTON(p->watch)->active);
         gtk_gs_defaults_set_antialiased(GTK_TOGGLE_BUTTON(p->aa)->active);
-        gtk_gs_defaults_set_override_media(GTK_TOGGLE_BUTTON(p->override_media)->active);
+        gtk_gs_defaults_set_override_size(GTK_TOGGLE_BUTTON(p->override_size)->active);
         gtk_gs_defaults_set_override_orientation(GTK_TOGGLE_BUTTON(p->override_orientation)->active);
         gtk_gs_defaults_set_show_scroll_rect(GTK_TOGGLE_BUTTON(p->show_scroll_rect)->active);
 
