@@ -256,9 +256,9 @@ gtk_gs_init (GtkGS *gs)
         gs->override_orientation = gtk_gs_defaults_get_override_orientation();
         gs->fallback_orientation = gtk_gs_defaults_get_orientation();
         gs->zoom_factor = gtk_gs_defaults_get_zoom_factor();
-        gs->default_media = gtk_gs_defaults_get_media();
+        gs->default_size = gtk_gs_defaults_get_size();
         gs->antialiased = gtk_gs_defaults_get_antialiased();
-        gs->override_media = gtk_gs_defaults_get_override_media();
+        gs->override_size = gtk_gs_defaults_get_override_size();
         gs->respect_eof = gtk_gs_defaults_get_respect_eof();
         gs->watch_doc = gtk_gs_defaults_get_watch_doc();
         gs->show_scroll_rect = gtk_gs_defaults_get_show_scroll_rect();
@@ -326,14 +326,14 @@ gtk_gs_defaults_changed(GConfClient* client, guint cnxn_id,
         else if(!strcmp(entry->key, "/apps/ggv/gtkgs/zoom"))
                 gtk_gs_set_zoom(gs, gconf_client_get_float(client, "/apps/ggv/gtkgs/zoom",
                                                            NULL));
-        else if(!strcmp(entry->key, "/apps/ggv/gtkgs/media"))
-                gtk_gs_set_default_media(gs, gconf_client_get_int(client, "/apps/ggv/gtkgs/media",
+        else if(!strcmp(entry->key, "/apps/ggv/gtkgs/size"))
+                gtk_gs_set_default_size(gs, gconf_client_get_int(client, "/apps/ggv/gtkgs/size",
                                                                   NULL));
         else if(!strcmp(entry->key, "/apps/ggv/gtkgs/antialiasing"))
                 gtk_gs_set_antialiasing(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/antialiasing",
                                                                   NULL));
-        else if(!strcmp(entry->key, "/apps/ggv/gtkgs/override_media"))
-                gtk_gs_set_override_media(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/override_media",
+        else if(!strcmp(entry->key, "/apps/ggv/gtkgs/override_size"))
+                gtk_gs_set_override_size(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/override_size",
                                                                     NULL));
         else if(!strcmp(entry->key, "/apps/ggv/gtkgs/watch_doc"))
                 gtk_gs_set_watch_file(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/watch_doc",
@@ -528,7 +528,7 @@ gtk_gs_realize (GtkWidget *widget)
         gs->width = 0;
         gs->height = 0;
 
-        gtk_gs_set_page_media(gs, -1, 0);
+        gtk_gs_set_page_size(gs, -1, 0);
 
         if ((gs->width > 0) && (gs->height > 0) && GTK_WIDGET_REALIZED(gs)) {
 		gtk_gs_munge_adjustments (gs);
@@ -754,7 +754,7 @@ timer_callback (gpointer data)
 	if (!gs->busy && !stat(gs->gs_filename, &sbuf) &&
 	    (sbuf.st_mtime != gs->mtime) &&
 	    (time (NULL) - sbuf.st_mtime >= GTK_GS_WATCH_TIMEOUT))
-		gtk_gs_set_page_media(gs, -1, gs->current_page);
+		gtk_gs_set_page_size(gs, -1, gs->current_page);
 
         return TRUE;
 }
@@ -1793,15 +1793,15 @@ gtk_gs_goto_page (GtkGS *gs, gint page)
 }
 
 /*
- * set pagemedia sets the media from
- * if new_pagemedia is -1, then it is set to either
+ * set pagesize sets the size from
+ * if new_pagesize is -1, then it is set to either
  *  a) the default settings of pageid, if they exist, or if pageid != -1.
  *  b) the default setting of the document, if it exists.
  *  c) the default setting of the widget.
- * otherwise, the new_pagemedia is used as the pagemedia
+ * otherwise, the new_pagesize is used as the pagesize
  */
 gboolean
-gtk_gs_set_page_media(GtkGS *gs, gint new_pagemedia, gint pageid)
+gtk_gs_set_page_size(GtkGS *gs, gint new_pagesize, gint pageid)
 {
         gint new_llx = 0;
         gint new_lly = 0;
@@ -1812,21 +1812,21 @@ gtk_gs_set_page_media(GtkGS *gs, gint new_pagemedia, gint pageid)
         g_return_val_if_fail(gs != NULL, FALSE);
         g_return_val_if_fail(GTK_IS_GS(gs), FALSE);
 
-        if(new_pagemedia == -1) {
-                new_pagemedia = gs->default_media;
-                if (!gs->override_media && gs->doc) {
+        if(new_pagesize == -1) {
+                new_pagesize = gs->default_size;
+                if (!gs->override_size && gs->doc) {
                         /* If we have a document:
-                           We use -- the page media (if specified)
-                                  or the doc. media (if specified)
+                           We use -- the page size (if specified)
+                                  or the doc. size (if specified)
                                   or the page bbox (if specified)
                                   or the bounding box
                           */
                         if ((pageid >= 0) && (gs->doc->numpages > pageid) &&
-                            (gs->doc->pages) && (gs->doc->pages[pageid].media)) {
-                                new_pagemedia = gs->doc->pages[pageid].media - gs->doc->media;
+                            (gs->doc->pages) && (gs->doc->pages[pageid].size)) {
+                                new_pagesize = gs->doc->pages[pageid].size - gs->doc->size;
                         }
-                        else if (gs->doc->default_page_media != NULL) {
-                                new_pagemedia = gs->doc->default_page_media - gs->doc->media;
+                        else if (gs->doc->default_page_size != NULL) {
+                                new_pagesize = gs->doc->default_page_size - gs->doc->size;
                         }
                         else if((pageid >= 0) &&
                                 (gs->doc->numpages > pageid) &&
@@ -1835,11 +1835,11 @@ gtk_gs_set_page_media(GtkGS *gs, gint new_pagemedia, gint pageid)
                                  gs->doc->pages[pageid].boundingbox[LLX]) &&
                                 (gs->doc->pages[pageid].boundingbox[URY] >
                                  gs->doc->pages[pageid].boundingbox[LLY])) {
-                                new_pagemedia = -1;
+                                new_pagesize = -1;
                         }
                         else if((gs->doc->boundingbox[URX] > gs->doc->boundingbox[LLX]) &&
                                 (gs->doc->boundingbox[URY] > gs->doc->boundingbox[LLY])) {
-                                new_pagemedia = -1;
+                                new_pagesize = -1;
                         }
                 }
         }
@@ -1847,10 +1847,10 @@ gtk_gs_set_page_media(GtkGS *gs, gint new_pagemedia, gint pageid)
         /* Compute bounding box */
         if (!gs->doc) {
                 new_llx = new_lly = 0;
-                new_urx = papersizes[new_pagemedia].width;
-                new_ury = papersizes[new_pagemedia].height;
+                new_urx = papersizes[new_pagesize].width;
+                new_ury = papersizes[new_pagesize].height;
         }
-        else if ((gs->doc->epsf || new_pagemedia == -1)) { /* epsf or bbox */
+        else if ((gs->doc->epsf || new_pagesize == -1)) { /* epsf or bbox */
                 if((gs->doc->pages) &&
                    (gs->doc->pages[pageid].boundingbox[URX] > gs->doc->pages[pageid].boundingbox[LLX]) &&
                    (gs->doc->pages[pageid].boundingbox[URY] > gs->doc->pages[pageid].boundingbox[LLY])) {
@@ -1868,17 +1868,17 @@ gtk_gs_set_page_media(GtkGS *gs, gint new_pagemedia, gint pageid)
                         new_urx = gs->doc->boundingbox[URX];
                         new_ury = gs->doc->boundingbox[URY];
                 }
-                new_pagemedia = gs->default_media;
+                new_pagesize = gs->default_size;
         }
         else {
                 new_llx = new_lly = 0;
-                if (!gs->override_media && gs->doc->media &&
-                    (new_pagemedia < gs->doc->nummedia)) {
-                        new_urx = gs->doc->media[new_pagemedia].width;
-                        new_ury = gs->doc->media[new_pagemedia].height;
+                if (!gs->override_size && gs->doc->size &&
+                    (new_pagesize < gs->doc->numsizes)) {
+                        new_urx = gs->doc->size[new_pagesize].width;
+                        new_ury = gs->doc->size[new_pagesize].height;
                 } else {
-                        new_urx = papersizes[new_pagemedia].width;
-                        new_ury = papersizes[new_pagemedia].height;
+                        new_urx = papersizes[new_pagesize].width;
+                        new_ury = papersizes[new_pagesize].height;
                 }
         }
 
@@ -1935,15 +1935,15 @@ gtk_gs_get_override_orientation(GtkGS *gs)
 }
 
 void
-gtk_gs_set_override_media(GtkGS *gs, gboolean f)
+gtk_gs_set_override_size(GtkGS *gs, gboolean f)
 {
         g_return_if_fail(gs != NULL);
         g_return_if_fail(GTK_IS_GS(gs));
 
-        if(f != gs->override_media) {
-                gs->override_media = f;
+        if(f != gs->override_size) {
+                gs->override_size = f;
                 gs->changed = TRUE;
-                gtk_gs_set_page_media(gs, -1, gs->current_page);
+                gtk_gs_set_page_size(gs, -1, gs->current_page);
                 if(GTK_WIDGET_REALIZED(gs))
                         set_up_page(gs);
         }
@@ -1951,12 +1951,12 @@ gtk_gs_set_override_media(GtkGS *gs, gboolean f)
 }
 
 gboolean
-gtk_gs_get_override_media(GtkGS *gs)
+gtk_gs_get_override_size(GtkGS *gs)
 {
         g_return_val_if_fail(gs != NULL, FALSE);
 	g_return_val_if_fail(GTK_IS_GS(gs), FALSE);
 
-        return gs->override_media;
+        return gs->override_size;
 }
 
 void
@@ -2054,22 +2054,22 @@ gtk_gs_get_orientation(GtkGS *gs)
 }
 
 void
-gtk_gs_set_default_media(GtkGS *gs, gint media)
+gtk_gs_set_default_size(GtkGS *gs, gint size)
 {
         g_return_if_fail(gs != NULL);
         g_return_if_fail(GTK_IS_GS(gs));
 
-        gs->default_media = media;
-        gtk_gs_set_page_media(gs, -1, gs->current_page);
+        gs->default_size = size;
+        gtk_gs_set_page_size(gs, -1, gs->current_page);
 }
 
 gint
-gtk_gs_get_default_media(GtkGS *gs)
+gtk_gs_get_default_size(GtkGS *gs)
 {
         g_return_val_if_fail(gs != NULL, -1);
         g_return_val_if_fail(GTK_IS_GS(gs), -1);
 
-        return gs->default_media;
+        return gs->default_size;
 }
 
 void
@@ -2082,7 +2082,7 @@ gtk_gs_set_respect_eof(GtkGS *gs, gboolean f)
                 return;
 
         gs->respect_eof = f;
-        gtk_gs_set_page_media(gs, -1, gs->current_page);
+        gtk_gs_set_page_size(gs, -1, gs->current_page);
 }
 
 gint
@@ -2201,12 +2201,12 @@ gtk_gs_count_marked_pages(GtkGS *widget)
 }
 
 gint
-gtk_gs_get_media_index(gchar *string, GtkGSPaperSize *media)
+gtk_gs_get_size_index(gchar *string, GtkGSPaperSize *size)
 {
         guint idx = 0;
 
-        while(media[idx].name != NULL) {
-                if(strcmp(media[idx].name, string) == 0)
+        while(size[idx].name != NULL) {
+                if(strcmp(size[idx].name, string) == 0)
                         return idx;
                 idx++;
         }
