@@ -103,8 +103,8 @@ struct _GtkGS
 	gboolean    watch_doc;                /* Automatic reload if file changed */
         gboolean    antialiased;              /* Using antialiased display */
         gboolean    respect_eof;              /* respect EOF comments? */
-        gint        default_media;
-        gboolean    override_media;
+        gint        default_size;
+        gboolean    override_size;
         gfloat      xdpi, ydpi;
         gboolean    override_orientation;
         gint        fallback_orientation;  /* Orientation to use if override */
@@ -164,11 +164,11 @@ void         gtk_gs_disable_interpreter(GtkGS *gs);
 
 gint         gtk_gs_get_current_page(GtkGS *gs);
 gint         gtk_gs_get_page_count(GtkGS *gs);
-gboolean     gtk_gs_set_page_media(GtkGS *gs, gint new_pagemedia, gint pageid);
+gboolean     gtk_gs_set_page_size(GtkGS *gs, gint new_pagesize, gint pageid);
 gboolean     gtk_gs_set_default_orientation(GtkGS *gs, gint orientation);
 gint         gtk_gs_get_default_orientation(GtkGS *gs);
-void         gtk_gs_set_default_media(GtkGS *gs, gint media);
-gint         gtk_gs_get_default_media(GtkGS *gs);
+void         gtk_gs_set_default_size(GtkGS *gs, gint size);
+gint         gtk_gs_get_default_size(GtkGS *gs);
 void         gtk_gs_set_zoom(GtkGS *gs, gfloat zoom);
 gfloat       gtk_gs_get_zoom(GtkGS *gs);
 gfloat       gtk_gs_zoom_to_fit(GtkGS *gs, gboolean fit_width);
@@ -182,8 +182,8 @@ void         gtk_gs_set_antialiasing(GtkGS *gs, gboolean f);
 gboolean     gtk_gs_get_antialiasing(GtkGS *gs);
 void         gtk_gs_set_watch_file(GtkGS *gs, gboolean f);
 gboolean     gtk_gs_get_watch_file(GtkGS *gs);
-void         gtk_gs_set_override_media(GtkGS *gs, gboolean f);
-gboolean     gtk_gs_get_override_media(GtkGS *gs);
+void         gtk_gs_set_override_size(GtkGS *gs, gboolean f);
+gboolean     gtk_gs_get_override_size(GtkGS *gs);
 const gchar *gtk_gs_get_document_title(GtkGS *widget);
 guint        gtk_gs_get_document_numpages(GtkGS *widget);
 const gchar *gtk_gs_get_document_page_label(GtkGS *widget, int page);
@@ -195,7 +195,7 @@ void         gtk_gs_start_scroll(GtkGS *gs);
 void         gtk_gs_end_scroll(GtkGS *gs);
 
 /* utility functions */
-gint     gtk_gs_get_media_index(gchar *string, GtkGSPaperSize *media);
+gint     gtk_gs_get_size_index(gchar *string, GtkGSPaperSize *size);
 
 GConfClient *gtk_gs_get_gconf_client(void);
 
