@@ -27,7 +27,7 @@ gint ggv_default_height = DEFAULT_WINDOW_HEIGHT;
 gint file_sel_height = DEFAULT_FILE_SEL_HEIGHT;
 
 gboolean ggv_panel = TRUE, ggv_menubar = TRUE, ggv_toolbar = TRUE;
-gboolean ggv_auto_jump = TRUE;
+gboolean ggv_auto_jump = TRUE, ggv_toolbar_labels = FALSE;
 gint ggv_unit_index = 0;
 
 void
@@ -52,6 +52,9 @@ ggv_prefs_load()
 	ggv_toolbar = gconf_client_get_bool(gconf_client,
                                            "/apps/ggv/layout/showtoolbar",
                                            NULL);
+        ggv_toolbar_labels = gconf_client_get_bool(gconf_client,
+                                                   "/apps/ggv/layout/toolbarlabels",
+                                                   NULL);
         ggv_menubar = gconf_client_get_bool(gconf_client,
                                            "/apps/ggv/layout/showmenubar",
                                            NULL);
@@ -91,6 +94,8 @@ ggv_prefs_save()
                               ggv_panel, NULL);
 	gconf_client_set_bool(gconf_client, "/apps/ggv/layout/showtoolbar",
                               ggv_toolbar, NULL);
+        gconf_client_set_bool(gconf_client, "/apps/ggv/layout/toolbarlabels",
+                              ggv_toolbar_labels, NULL);
         gconf_client_set_bool(gconf_client, "/apps/ggv/layout/showmenubar",
                               ggv_menubar, NULL);
         gconf_client_set_bool(gconf_client, "/apps/ggv/layout/autojump",
@@ -138,6 +143,12 @@ ggv_prefs_changed(GConfClient* client, guint cnxn_id,
                                                     NULL);
                 ggv_prefs_apply(window_list);
         }
+        else if(!strcmp(entry->key, "/apps/ggv/layout/toolbarlabels")) {
+                ggv_toolbar_labels = gconf_client_get_bool(gconf_client,
+                                                           "/apps/ggv/layout/toolbarlabels",
+                                                           NULL);
+                ggv_prefs_apply(window_list);
+        }
         else if(!strcmp(entry->key, "/apps/ggv/layout/showmenubar")) {
                 ggv_menubar = gconf_client_get_bool(gconf_client,
                                                     "/apps/ggv/layout/showmenubar",
